pub struct TrackedSubprocess { /* private fields */ }Expand description
Tracks the PID of a subprocess for as long as it’s running, so it can be killed on demand from anywhere holding a reference to this struct.
Implementations
Sourceimpl TrackedSubprocess
impl TrackedSubprocess